package com.ti.msp430.iec60730.configTool;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.text.ParseException;

public class CRC16CCITT { 
	File memoryFile;
	int initialValue;
	
	
	public File getMemoryFile() {
		return memoryFile;
	}

	public void setMemoryFile(File memoryFile) {
		this.memoryFile = memoryFile;
	}

	public int getInitialValue() {
		return initialValue;
	}

	public void setInitialValue(int initialValue) {
		this.initialValue = initialValue;
	}

	
	public CRC16CCITT(String filePath, int initialValue){
		this.memoryFile = new File(filePath);
		this.initialValue = initialValue; 
	}
	
	
	
	

    public String calculateCRC() throws IOException { 
        int crc = getInitialValue();	// initial value
        // Polynomial for CRC16-CCITT
        int polynomial = 0x1021;   		// 0001 0000 0010 0001  (0, 5, 12) 
        byte b;

			String fileName = getMemoryFile().getAbsolutePath(); 
			BufferedReader br = new BufferedReader(new FileReader(fileName));
			
		    	try {
		    		// For memory file generated by CCS
		    		if(fileName.contains(".dat")){
		            String line = br.readLine();
		
		            while (line != null) {
		                line = br.readLine();
		                
		                if(line!=null){
		                	b=(byte) Integer.parseInt(line.substring(4,6), 16);
		                
		
		                	for (int i = 0; i < 8; i++) {
		                		boolean bit = ((b   >> (7-i) & 1) == 1);
		                		boolean c15 = ((crc >> 15    & 1) == 1);
		                		crc <<= 1;
		                		if (c15 ^ bit) crc ^= polynomial;
		                	}
		                	
		                	b=(byte) Integer.parseInt(line.substring(2,4), 16);
		                	
		                	for (int i = 0; i < 8; i++) {
		                		boolean bit = ((b   >> (7-i) & 1) == 1);
		                		boolean c15 = ((crc >> 15    & 1) == 1);
		                		crc <<= 1;
		                		if (c15 ^ bit) crc ^= polynomial;
		                	}
		                	
		                }
		                
		            }
		            // for memory file generated by IAR
		        }else if(fileName.contains(".txt")){
		        	// Ignore file memory information
		        	 String line = br.readLine();
		     		
			            while (line!= null) {
			                line = br.readLine();
			                if (line !=null){
				                String[] byteRead = line.split(" ");
				            
				                for(String memoryByte: byteRead){
				                	if(!memoryByte.contains("q")){
				                		b=(byte) Integer.parseInt(memoryByte.replace(" ", ""), 16);
				                		if(!memoryByte.contains("q")){
				                		
				                			for (int i = 0; i < 8; i++) {
						                		boolean bit = ((b   >> (7-i) & 1) == 1);
						                		boolean c15 = ((crc >> 15    & 1) == 1);
						                		crc <<= 1;
						                		if (c15 ^ bit) crc ^= polynomial;
				                		
				                			}
				                		}
				                	}
				                }
			                }
			            }
		        }
           
	        } finally {
	            br.close();
	        }
		    	
        crc &= 0xffff;
        return "0x" + Integer.toHexString(crc).toUpperCase(); 
    }
    
}
