package com.ti.msp430.iec60730.configTool;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.ObjectInputStream.GetField;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.regex.Pattern;

import com.ti.msp430.iec60730.configTool.Iec60730ConfigUI.GuiInformation;

public class HeaderFile {
	File outputFile;
	GuiInformation guiInfo;
	
	
	public File getOutputFile() {
		return outputFile;
	}

	public void setOutputFile(File outputFile) {
		this.outputFile = outputFile;
	}

	public GuiInformation getGuiInfo() {
		return guiInfo;
	}

	public void setGuiInfo(GuiInformation guiInfo) {
		this.guiInfo = guiInfo;
	}
	
	
	public HeaderFile(String filePath, GuiInformation guiInfo){
		this.outputFile = new File(filePath);
		this.guiInfo = guiInfo;
	}
	
	public void createHeaderFile(){
		
		try {
			 
			System.out.println("Creating Header file: " + outputFile.getAbsolutePath());
 
			
 
			// Verify file exist if not create it
			if (!outputFile.exists()) {
				outputFile.createNewFile();
			}
 
			FileWriter fw = new FileWriter(outputFile.getAbsoluteFile());
			BufferedWriter bw = new BufferedWriter(fw);
			addBSDLicense(bw);
			addDefines(bw);
			startUserDefinitions(bw);
			watchDogDefintion(bw);
			jumpToFailSafeDefintion(bw);
			clkDefinitions(bw);
			ramDefinitions(bw);
			nvmDefinitions(bw);
			adcDefinitions(bw);
			testCodesDefinitions(bw);
			finishHeader(bw);
			
			
			
			
			
			bw.close();
 
			System.out.println("Done");
 
		} catch (IOException e) {
			e.printStackTrace();
		}
		
	}
	
	private void addBSDLicense(BufferedWriter bw) throws IOException{
		bw.write("/* --COPYRIGHT--,BSD\n");
		bw.write(" * Copyright (c) 2012, Texas Instruments Incorporated\n");
		bw.write(" * All rights reserved.\n");
		bw.write(" *\n");
		bw.write(" * Redistribution and use in source and binary forms, with or without\n");
		bw.write(" * modification, are permitted provided that the following conditions\n");
		bw.write(" * are met:\n");
		bw.write(" *\n");
		bw.write(" * *  Redistributions of source code must retain the above copyright\n");
		bw.write(" *    notice, this list of conditions and the following disclaimer.\n");
		bw.write(" *\n");
		bw.write(" * *  Redistributions in binary form must reproduce the above copyright\n");
		bw.write(" *    notice, this list of conditions and the following disclaimer in the\n");
		bw.write(" *    documentation and/or other materials provided with the distribution.\n");
		bw.write(" *\n");
		bw.write(" * *  Neither the name of Texas Instruments Incorporated nor the names of\n");
		bw.write(" *    its contributors may be used to endorse or promote products derived\n");
		bw.write(" *    from this software without specific prior written permission.\n");
		bw.write(" *\n");
		bw.write(" * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\n");
		bw.write(" * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,\n");
		bw.write(" * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR\n");
		bw.write(" * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR\n");
		bw.write(" * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,\n");
		bw.write(" * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,\n");
		bw.write(" * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;\n");
		bw.write(" * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,\n");
		bw.write(" * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR\n");
		bw.write(" * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,\n");
		bw.write(" * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n");
		bw.write(" * --/COPYRIGHT--*/\n");
		bw.write("\n");
	}
	
	private void addDefines(BufferedWriter bw) throws IOException {
		bw.write("#ifndef _IEC60730_USER_CONFIG_H_\n");
		bw.write("#define _IEC60730_USER_CONFIG_H_\n");
		bw.write("\n");
		bw.write("#include <msp430.h>");
		bw.write("\n");
		bw.write("#ifdef __cplusplus\n");
		bw.write("extern \"C\"\n");
		bw.write("{\n");
		bw.write("#endif\n");
		
	}
	
	
	private void startUserDefinitions(BufferedWriter bw) throws IOException {
		bw.write("\n//***************************************************************************************\n");
		bw.write("// Start of User Options\n");
		bw.write("//***************************************************************************************\n\n");
		
	}
	
	private void watchDogDefintion(BufferedWriter bw) throws IOException {
		bw.write("//***************************************************************************************\n");
		bw.write("// FOR WATCHDOG TIMER options\n");
		bw.write("// Section to define if WDT is enabled 0=disabled 1= enabled\n");
		bw.write("//***************************************************************************************\n");
		
		
		if(guiInfo.isWdtflag()==true){
			bw.write("#define ENABLED_WDT\t\t\t\t1\n\n");
		}else{
			bw.write("#define ENABLED_WDT\t\t\t\t0\n\n");
		}
		
	}
	
	private void jumpToFailSafeDefintion(BufferedWriter bw) throws IOException {
		bw.write("//***************************************************************************************\n");
		bw.write("// Define to handle test failures\n");
		bw.write("//\n");
		bw.write("// Section to define if JUMP_TO_FAILSAFE is enabled 0=disabled 1= enabled\n");
		bw.write("//\n");
		bw.write("// If JUMP_TO_FAILSAFE is enabled the user must create a function called\n");
		bw.write("// \"IEC60730_FAIL_SAFE_failSafe(void)\" to handle the failure of any test\n");
		bw.write("//\n");
		bw.write("// If JUMP_TO_FAILSAFE is disabled all test will return TEST_FAILURE.\n");
		bw.write("//***************************************************************************************\n");
		
		
		if(getGuiInfo().isJumpToFailSafe()==true){
			bw.write("#define JUMP_TO_FAILSAFE\t\t1\n");
		}else{
			bw.write("#define JUMP_TO_FAILSAFE\t\t0\n");
		}
		
	}
	
	private void clkDefinitions(BufferedWriter bw) throws IOException {
		bw.write("//***************************************************************************************\n");
		bw.write("// Defines for OSCILLATOR_TEST\n");
		bw.write("//***************************************************************************************\n\n");
		bw.write("//***************************************************************************************\n");
		bw.write("// Defines to specify which Timer_Ax and CCRn to be used for Oscillator fault test\n");
		bw.write("// You must define one one USE_TAx and and one USE_CCRn. Otherwise, the test may\n");
		bw.write("// result in unexpected beahvior.\n");
		bw.write("//\n");
		bw.write("// NOTE: The selected Timer_Ax and CCRn must be available in the device. If the selected\n");
		bw.write("// timer is not available in the device, the project will throw compilation errors.\n");
		bw.write("//***************************************************************************************\n");
		
		switch (getGuiInfo().getTimertype()) {
		case 0:
			bw.write("#define USE_TA0\n\n");
			break;
			
		case 1:
			bw.write("#define USE_TA1\n\n");
			break;
			
		case 2:
			bw.write("#define USE_TA2\n\n");
			break;

		default:
			break;
		}
		
		
		
		switch (getGuiInfo().getCcrValue()) {
		case 0:
			bw.write("#define USE_CCR0\n\n");
			break;
		case 1:
			bw.write("#define USE_CCR1\n\n");
			break;
		case 2:
			bw.write("#define USE_CCR2\n\n");
			break;
		case 3:
			bw.write("#define USE_CCR3\n\n");
			break;
		case 4:
			bw.write("#define USE_CCR4\n\n");
			break;

		default:
			break;
		}
		
		bw.write("//***************************************************************************************\n");
		bw.write("// Define to specify the MCLK frequency\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define MAIN_CLOCK_FREQUENCY\t\t\t"+ getGuiInfo().getMainClkFreq()+"\n\n");
		
		bw.write("//***************************************************************************************\n");
		bw.write("// Define to specify divider of Main Clock\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define MAIN_CLOCK_DIVIDER\t\t\t"+ getGuiInfo().getMainClkDiv()+"\n\n");
		
		bw.write("//***************************************************************************************\n");
		bw.write("// Defines to provide information regarding independent clock source that will be used to\n");
		bw.write("// monitor the main clock source\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define LFXT1_FREQUENCY\t\t\t"+ getGuiInfo().getAclkFrequency()+"\n");
		bw.write("#define LFXT1_FREQUENCY_DIVIDER\t"+ getGuiInfo().getAclkDivider()+"\n\n");
		
		bw.write("//***************************************************************************************\n");
		bw.write("// Defines to provide determine the allowed frequency drift of the main clock (in +/- %)\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define PERCENT_FREQUENCY_DRIFT\t\t\t"+ getGuiInfo().getPercentFrequency()+"\n\n\n");
		
	}
	
	private void ramDefinitions(BufferedWriter bw) throws IOException {
		bw.write("//***************************************************************************************\n");
		bw.write("// Defines for RAM MEMORY test\n");
		bw.write("//***************************************************************************************\n\n");
		bw.write("//***************************************************************************************\n");
		bw.write("// The following defines determine the parameters that will be passed to\n");
		bw.write("// IEC60730_MARCH_TEST_testRam(). The values for RAM_START_ADDRESS and RAM_SIZE\n");
		bw.write("// can be obtain in the device datasheet. The stack size can be determine from your\n");
		bw.write("// compiler configuration setting.\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define RAM_START_ADDRESS\t\t\t"+ getGuiInfo().getRamStartAddress()+"\n");
		bw.write("#define RAM_SIZE\t\t\t\t\t"+ getGuiInfo().getRamSize()+"\n");
		bw.write("#define STACK_SIZE\t\t\t\t\t"+ getGuiInfo().getStackSize()+"\n\n");
		
		bw.write("//***************************************************************************************\n");
		bw.write("// The following defines is calculated based on the defines above. This define should\n");
		bw.write("// not be modified.\n");
		bw.write("//***************************************************************************************\n");		
		bw.write("#define RAM_END_ADDRESS\t\t\t((RAM_START_ADDRESS + RAM_SIZE)-STACK_SIZE)\n");
		
		bw.write("//***************************************************************************************\n");
		bw.write("// The following define selects the type of MARCH test to be implemented in the RAM\n");
		bw.write("// TEST.\n");
		bw.write("//***************************************************************************************\n");
		
			
		switch (getGuiInfo().getMarchTestType()) {
		case 0:
			bw.write("#define MARCH_C_TEST\n\n");
			break;
			
		case 1:
			bw.write("#define MARCH_X_TEST\n\n");
			break;
		default:
			break;
		}
		
		
		
		if(getGuiInfo().isDestructive()==true){
			
			bw.write("//***************************************************************************************\n");
			bw.write("// The following defines allows the configuration of selected MARCH test in\n");
			bw.write("//  NON-DESTRUCTIVE mode.\n");
			bw.write("//***************************************************************************************\n");
			bw.write("#define NON_DESTRUCTIVE\n\n");
			
			bw.write("//***************************************************************************************\n");
			bw.write("// The following define is used if NON-DESTRUCTIVE for march test is selected\n");
			bw.write("//***************************************************************************************\n");
			bw.write("#define RAM_TEST_BUFSIZE\t\t\t"+getGuiInfo().getRamTestBuffer()/2 +"\n\n");
		}
		
		
	}
	
	private void nvmDefinitions(BufferedWriter bw) throws IOException {
		bw.write("//***************************************************************************************\n");
		bw.write("// Defines for NON VOLATILE MEMORY test\n");
		bw.write("//***************************************************************************************\n\n");
		bw.write("//***************************************************************************************\n");
		bw.write("// Definitions required for software implementation of CRC16-CCITT the default seed is\n");
		bw.write("// (0xFFFF) and the polynomial used is x^16+x^12+x^5+1\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define CRC16_CCITT_SEED\t\t\t"+ getGuiInfo().getCcrValue()+"\n");

		
		bw.write("//***************************************************************************************\n");
		bw.write("// If library is being complied for an MSP430 device that does not have a CRC module\n");
		bw.write("// CRC16_CCITT_POLY will be automatically defined\n");
		bw.write("//***************************************************************************************\n");		
		bw.write("#ifndef __MSP430_HAS_CRC__\n");
		bw.write("#define CRC16_CCITT_POLY\t\t\t0x1021\n");
		bw.write("#endif\n");
		
		
		bw.write("//***************************************************************************************\n");
		bw.write("// The following define specifies the start location in Flash where CRC check sumsums\n");
		bw.write("// are stored.\n");
		bw.write("// Specify the address where CRC result is located.\n");
		bw.write("// Note: Ideally the location will be in the information memory section of the device.\n");
		bw.write("// To determine the address for the information memory for each device please reffer to\n");
		bw.write("// the device datasheet and locate the \"Memory Organization\" section in the datasheet.\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define CRC_CHECKSUM_LOCATION\t\t\t\t"+guiInfo.getCheckSumLocation()+"\n\n");
		
	}
	
	private void adcDefinitions(BufferedWriter bw) throws IOException {
		bw.write("//***************************************************************************************\n");
		bw.write("// Defines for ADC test\n");
		bw.write("//***************************************************************************************\n\n");
		bw.write("//***************************************************************************************\n");
		bw.write("// The following defines specify the maximum and minimum ADC conversion count drift\n");
		bw.write("// allowed in the application\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define MINIMUM_ADC_COUNT_DRIFT\t\t\t"+guiInfo.getMinADCDrift()+"\n");
		bw.write("#define MAXIMUM_ADC_COUNT_DRIFT\t\t\t"+guiInfo.getMaxADCDrift()+"\n\n");		
	}
	
	private void testCodesDefinitions(BufferedWriter bw) throws IOException {
		HashMap<String, String> codes = getGuiInfo().getTestCodes();
		
		bw.write("//***************************************************************************************\n");
		bw.write("// Section to define all the sucess codes\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define SIG_CPU_REG_TEST\t\t\t0xCC\n");
		bw.write("#define SIG_PC_REG_TEST\t\t\t\t"+codes.get("PC_code")+"\n");
		bw.write("#define SIG_CLOCK_TEST\t\t\t\t"+codes.get("CLOCK_code")+"\n");
		bw.write("#define SIG_RAM_TEST\t\t\t\t"+codes.get("RAM_code")+"\n");
		bw.write("#define SIG_NV_MEM_CRC_TEST\t\t\t"+codes.get("NV_code")+"\n");
		bw.write("#define SIG_ADC_TEST\t\t\t\t"+codes.get("ADC_code")+"\n");
		bw.write("#define SIG_GPIO_TEST\t\t\t\t"+codes.get("GPIO_code")+"\n");
		bw.write("#define SIG_INTERRUPT_TEST\t\t\t"+codes.get("INTERRUPT_code")+"\n\n");
		
		bw.write("//***************************************************************************************\n");
		bw.write("// Section to define failure code.\n");
		bw.write("// The following failure code will be return by IEC60730 APIs\n");
		bw.write("//***************************************************************************************\n");
		bw.write("#define TEST_FAILURE\t\t\t\t"+codes.get("FAILURE_code")+"\n\n");
	}
	
	
	
	private void finishHeader(BufferedWriter bw) throws IOException {
		bw.write("\n\n//***************************************************************************************\n");
		bw.write("//End user Options\n");
		bw.write("//***************************************************************************************\n");
		bw.write("\n");
		bw.write("#ifdef __cplusplus\n");
		bw.write("}\n");
		bw.write("#endif\n");
		bw.write("\n");
		bw.write("#endif\n");
	}
	
}

