package com.ti.msp430.iec60730.configTool;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.regex.Pattern;



public class MemoryFile {
	File outputFile;
	int memoryFileType;
	String memoryLocation;
	ArrayList<String> crcCheckSum;
	
	public File getOutputFile() {
		return outputFile;
	}

	public void setOutputFile(File outputFile) {
		this.outputFile = outputFile;
	}

	public String getMemoryLocation() {
		return memoryLocation;
	}

	public void setMemoryLocation(String memoryLocation) {
		this.memoryLocation = memoryLocation;
	}

	public ArrayList<String> getCrcCheckSum() {
		return crcCheckSum;
	}

	public void setCrcCheckSum(ArrayList<String> crcCheckSum) {
		this.crcCheckSum = crcCheckSum;
	}

	public int getMemoryFileType() {
		return memoryFileType;
	}

	public void setMemoryFileType(int memoryFileType) {
		this.memoryFileType = memoryFileType;
	}

	
	
	public MemoryFile(File file, int memoryFileType, String memoryLocation , ArrayList<String> crcCheckSums){
		this.outputFile = file;
		this.memoryFileType = memoryFileType;
		this.memoryLocation = memoryLocation;
		this.crcCheckSum  = crcCheckSums;
	}
	
	
	

	public String createMemoryFile(){
		try {
			 
			for(String checksum:getCrcCheckSum()){
				if(isHexValue(checksum,4)==false){
					return "Error: File contains invalid hex values.";
				}
			}
 
			FileWriter fw = new FileWriter(outputFile.getAbsoluteFile());
			BufferedWriter bw = new BufferedWriter(fw);
			
			addDatHeader(bw);
			
			addCrcChecksums(bw);
			
			finishMemoryFile(bw);
			
			
			bw.close();
 
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		return "SUCESS";
		
		
	}
	
	private void addDatHeader(BufferedWriter bw) throws IOException {
		if(getMemoryFileType()==0){
			bw.write("1651 9 " + getMemoryLocation().substring(2) + " 0 " + getCrcCheckSum().size() + " 7 \n");
		}else if(getMemoryFileType()==1){
			bw.write("@" + memoryLocation.substring(2) +"\n");
		}
		
	}
	
	private void addCrcChecksums(BufferedWriter bw) throws IOException {
		if(getMemoryFileType()==0){
			for(String checksum: getCrcCheckSum()){
				bw.write(checksum+ "\n");
			}
		}else if(getMemoryFileType()==1){
			int i=1;
			for(String checksum: getCrcCheckSum()){
				if(i<getCrcCheckSum().size()){
					bw.write(checksum.substring(4 , 6) +" ");
					bw.write(checksum.substring(2 , 4) +" ");
					i++;
				}else{
					bw.write(checksum.substring(4 , 6) +" ");
					bw.write(checksum.substring(2 , 4) +"\n");
				}
			}
		}
		
	}
	
	private void finishMemoryFile(BufferedWriter bw) throws IOException {
		if(getMemoryFileType()==1){
			bw.write("q");
		}
	}


	
	
    private boolean isHexValue(String value, int length){
    	// Must start with 0x has to be of length 4 and contain valid hex values
    	String HEX_PATTERN = "^0x[A-Fa-f0-9]{"+ Integer.toString(length)+"}$";
    	Pattern pattern = Pattern.compile(HEX_PATTERN);
    	
		if(pattern.matcher(value).matches()){
			return true;
		}
    	    	
    	return false;
    }
    
}
